@@ -1,4 +1,4 @@
-# $Id: HTML4.pm,v 1.14 2003/12/19 21:23:37 petdance Exp $
+# $Id: HTML4.pm,v 1.15 2004/01/27 23:15:16 petdance Exp $
 package HTML::Lint::HTML4;
 
 use strict;
@@ -61,10 +61,14 @@ sub _ns_only { return @_ };
     dd		=> _hash( @std ),
     dl		=> _hash( @std, qw( compact ) ),
     dt		=> _hash( @std ),
+    embed	=> _hash(
+		    qw( align height hidden name palette src units width ),
+		    _ns_only( qw( border hspace pluginspace type vspace ) ),
+		    ),
     fieldset	=> _hash( @std ),
     font	=> _hash( @core, @i18n, qw( color face size ) ),
     form	=> _hash( @std, qw( accept-charset action enctype method name onreset onsubmit target ) ),
-    frame 	=> _hash( @core, qw( frameborder longdesc marginheight marginwidth name noresize scrolling src ) ),
+    frame	=> _hash( @core, qw( frameborder longdesc marginheight marginwidth name noresize scrolling src ) ),
     frameset	=> _hash( @core, qw( cols onload onunload rows ) ),
     h1		=> _hash( @std, qw( align ) ),
     h2		=> _hash( @std, qw( align ) ),
@@ -77,15 +81,15 @@ sub _ns_only { return @_ };
     html	=> _hash( @i18n, qw( version )),
     iframe	=> _hash( @core, qw( align frameborder height longdesc marginheight marginwidth name scrolling src width ) ),
     img		=> _hash( @std, qw( align alt border height hspace ismap longdesc name src usemap vspace width ) ),
-    input 	=> _hash( @std, qw( accept accesskey align alt border checked disabled maxlength name onblur onchange onfocus onselect readonly size src tabindex type usemap value ) ),
+    input	=> _hash( @std, qw( accept accesskey align alt border checked disabled maxlength name onblur onchange onfocus onselect readonly size src tabindex type usemap value ) ),
     ins		=> _hash( @std, qw( cite datetime ) ),
     isindex	=> _hash( @core, @i18n, qw( prompt ) ),
-    label 	=> _hash( @std, qw( accesskey for onblur onfocus ) ),
+    label	=> _hash( @std, qw( accesskey for onblur onfocus ) ),
     legend	=> _hash( @std, qw( accesskey align ) ),
     li		=> _hash( @std, qw( type value ) ),
-    link	=> _hash( @std, qw( charset href hreflang media rel rev target type ) ),
+    'link'      => _hash( @std, qw( charset href hreflang media rel rev target type ) ),
     listing	=> _hash(),
-    map		=> _hash( @std, qw( name ) ),
+    'map'	=> _hash( @std, qw( name ) ),
     menu	=> _hash( @std, qw( compact ) ),
     meta	=> _hash( @i18n, qw( content http-equiv name scheme ) ),
     nobr	=> _hash( @std ),
@@ -95,22 +99,22 @@ sub _ns_only { return @_ };
     ol		=> _hash( @std, qw( compact start type ) ),
     optgroup	=> _hash( @std, qw( disabled label ) ),
     option	=> _hash( @std, qw( disabled label selected value ) ),
-    p 		=> _hash( @std, qw( align ) ),
-    param 	=> _hash( qw( id name type value valuetype ) ),
-    plaintext  	=> _hash(),
+    p		=> _hash( @std, qw( align ) ),
+    param	=> _hash( qw( id name type value valuetype ) ),
+    plaintext	=> _hash(),
     pre		=> _hash( @std, qw( width ) ),
-    q 		=> _hash( @std, qw( cite ) ),
+    q		=> _hash( @std, qw( cite ) ),
     script	=> _hash( qw( charset defer event for language src type ) ),
-    select	=> _hash( @std, qw( disabled multiple name onblur onchange onfocus size tabindex ) ),
+    'select'	=> _hash( @std, qw( disabled multiple name onblur onchange onfocus size tabindex ) ),
     span	=> _hash( @std ),
     strong	=> _hash(),
-    style 	=> _hash( @i18n, qw( media title type ) ),
-    table 	=> _hash( @std, 
+    style	=> _hash( @i18n, qw( media title type ) ),
+    table	=> _hash( @std, 
 		    qw( align bgcolor border cellpadding cellspacing datapagesize frame rules summary width ),
 		    _ie_only( qw( background bordercolor bordercolordark bordercolorlight ) ),
 		    _ns_only( qw( bordercolor cols height hspace vspace ) ),
 		    ),
-    tbody 	=> _hash( @std, qw( align char charoff valign ) ),
+    tbody	=> _hash( @std, qw( align char charoff valign ) ),
     td		=> _hash( @std, 
 		    qw( abbr align axis bgcolor char charoff colspan headers height nowrap rowspan scope valign width ),
 		    _ie_only( qw( background bordercolor bordercolordark bordercolorlight ) ),
@@ -120,9 +124,9 @@ sub _ns_only { return @_ };
 		    qw( abbr align axis bgcolor char charoff colspan headers height nowrap rowspan scope valign width ),
 		    _ie_only( qw( background bordercolor bordercolordark bordercolorlight ) ),
 		    ),
-    thead 	=> _hash( @std, qw( align char charoff valign ) ),
-    tfoot 	=> _hash( @std, qw( align char charoff valign ) ),
-    title 	=> _hash( @i18n ),
+    thead	=> _hash( @std, qw( align char charoff valign ) ),
+    tfoot	=> _hash( @std, qw( align char charoff valign ) ),
+    title	=> _hash( @i18n ),
     tr		=> _hash( @std, 
 		    qw( align bgcolor char charoff valign ),
 		    _ie_only( qw( bordercolor bordercolordark bordercolorlight nowrap ) ),
@@ -200,11 +204,11 @@ my %booger = (
 	{
 		'ALIGN',	 'BOTTOM|MIDDLE|TOP|LEFT|CENTER|RIGHT|JUSTIFY|'.
 				'BLEEDLEFT|BLEEDRIGHT|DECIMAL',
-		'ALINK' 	 => 'color',
+		'ALINK'		 => 'color',
 		'BGCOLOR'	   => 'color',
 		'CLEAR',	'LEFT|RIGHT|ALL|NONE',
-		'COLOR' 	 => 'color',
-		'COLS', 	 '\d+|(\d*[*%]?,)*\s*\d*[*%]?',
+		'COLOR'		 => 'color',
+		'COLS',		 '\d+|(\d*[*%]?,)*\s*\d*[*%]?',
 		'COLSPAN',	   '\d+',
 		'DIR'		=> 'LTR|RTL',
 		'HEIGHT',	   '\d+',
@@ -212,19 +216,19 @@ my %booger = (
 		'LINK'		=> 'color',
 		'MAXLENGTH',   '\d+',
 		'METHOD',	   'GET|POST',
-		'ROWS', 	   '\d+|(\d*[*%]?,)*\s*\d*[*%]?',
+		'ROWS',		   '\d+|(\d*[*%]?,)*\s*\d*[*%]?',
 		'ROWSPAN',	   '\d+',
 		'SEQNUM',	   '\d+',
-		'SIZE', 	   '[-+]?\d+|\d+,\d+',
-		'SKIP', 	   '\d+',
-		'TYPE', 	   'CHECKBOX|HIDDEN|IMAGE|PASSWORD|RADIO|RESET|'.
+		'SIZE',		   '[-+]?\d+|\d+,\d+',
+		'SKIP',		   '\d+',
+		'TYPE',		   'CHECKBOX|HIDDEN|IMAGE|PASSWORD|RADIO|RESET|'.
 				'SUBMIT|TEXT|[AaIi1]|disc|square|circle|'.
 				'FILE|.*',
 		'UNITS',	 'PIXELS|EN',
 		'VALIGN',	 'TOP|MIDDLE|BOTTOM|BASELINE',
-		'VLINK' 	 => 'color',
+		'VLINK'		 => 'color',
 		'WIDTH',	 '\d+%?',
-		'WRAP', 	 'OFF|VIRTUAL|PHYSICAL',
+		'WRAP',		 'OFF|VIRTUAL|PHYSICAL',
 		'X',		 '\d+',
 		'Y',		 '\d+'
 	},
